SlickGrid example 3: Editing

## Excel compatible copy/paste manager

Thanks to Celebio! (link to site)
This is basically the same example than example-spreadsheet.html, with the support of external excel-compatible software clipboard

## Paste from Excel-compatible:

- Copy a range of cells to clipboard in Excel
- Select a cell on slickgrid
- Use Ctrl-V keyboard shortcut to paste from the clipboard
- Adds rows to bottom of grid if paste overflows

## Copy for Excel-compatible:

- Select a range of cells with a mouse
- Use Ctrl-C shortcut to copy cells
- You can paste the tabular data into Excel

## Undo/redo support :

- Use buttons to undo/redo copy/paste

## View Source:

- View the source for this example on Github